# JZ3
> This project was partly based on the code from [z3-sudoku](https://github.com/awkwardbunny/z3-sudoku)

This project uses python z3-solver to benchmark encoding techniques to solving the same problem. 
It then compares the efficiency of each method and between different encoding techniques.

The link to the PyPi package is [https://pypi.org/project/jz3/](https://pypi.org/project/jz3/)
The link to the github repo is [https://github.com/Robert-Jia00129/jz3](https://github.com/Robert-Jia00129/jz3)

- `/solvers`: Houses executables and related files for various SMT solvers used in the project.

 for analyzing solver performance and generating images for reports or presentations.